# -*- coding: utf-8 -*-
"""
Created on Fri Oct 20 13:53:38 2017

@author: Charlie Shobe, University of Colorado

This script creates Figure 10 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 10 compares the erosion rate--channel steepness relationships from the 
constant-threshold and variable-threshold models. We also include the field
data compilation of Scherler et al (2017, JGR-ES).

INPUTS
------
One .csv file containing model results and field data.
"""

from __future__ import division
import numpy as np
import matplotlib.pyplot as plt
import matplotlib

#set plot font size parameter
matplotlib.rcParams.update({'font.size': 20})

#############import and parse data
data = np.genfromtxt('shobe_etal_fig10_data.csv', delimiter = ',', skip_header = 2)

#model results: variable-threshold models
gammapoint5_e = data[:, 0]
gammapoint5_ks = data[:, 1]
gamma2_e = data[:, 2]
gamma2_ks = data[:, 3]
gamma5_e = data[:, 4]
gamma5_ks = data[:, 5]

#model results: constant-threshold models
taucrit75_e = data[:, 6]
taucrit75_ks = data[:, 7]
taucrit150_e = data[:, 8]
taucrit150_ks = data[:, 9]
taucrit340_e = data[:, 10]
taucrit340_ks = data[:, 11]
basecase_e = data[:, 12]
basecase_ks = data[:, 13]

#cosmogenic erosion rates
cosmo_rates = data[:, 17]
cosmo_ksn = data[:, 21]

#break out cosmogenic data by study
godard2010_rates = cosmo_rates[0:9]
harkins2007_rates = cosmo_rates[9:17]
ouimet2009_rates = cosmo_rates[17:82]
godard2012_rates = cosmo_rates[82:90]
finnegan2008_rates = cosmo_rates[90:97]
wobus2005_rates = cosmo_rates[97:105]
scherler2014_rates = cosmo_rates[105:124]
godard2014_rates = cosmo_rates[124:]

godard2010_ksn = cosmo_ksn[0:9]
harkins2007_ksn = cosmo_ksn[9:17]
ouimet2009_ksn = cosmo_ksn[17:82]
godard2012_ksn = cosmo_ksn[82:90]
finnegan2008_ksn = cosmo_ksn[90:97]
wobus2005_ksn = cosmo_ksn[97:105]
scherler2014_ksn = cosmo_ksn[105:124]
godard2014_ksn = cosmo_ksn[124:]

#instantiate figure and subplot
fig = plt.figure(figsize=(10,6))
final_plot = plt.subplot()

##########plot everything

#constant thresh runs
final_plot.plot(taucrit340_e/1000, taucrit340_ks, linewidth = 3, linestyle = ':', c = 'r', label = r'$\tau_c=340$ Pa')
final_plot.plot(taucrit150_e/1000, taucrit150_ks, linewidth = 3, linestyle = ':', c = 'g', label = r'$\tau_c=150$ Pa')
final_plot.plot(taucrit75_e/1000, taucrit75_ks, linewidth = 3, linestyle = ':', c = 'k', label = r'$\tau_c=75$ Pa')


#variable thresh runs
final_plot.plot(gamma5_e/1000, gamma5_ks, linewidth = 3, c = 'r', label = r'$\gamma=5.0$ m$^{-2}$')
final_plot.plot(gamma2_e/1000, gamma2_ks, linewidth = 3, c = 'g', label = r'$\gamma=2.0$ m$^{-2}$')
final_plot.plot(gammapoint5_e/1000, gammapoint5_ks, linewidth = 3, c = 'k', label = r'$\gamma=0.5$ m$^{-2}$')

#plot cosmo data
#final_plot.scatter(cosmo_rates , cosmo_ksn, c = '0.5', edgecolor='0.5')

#plot cosmo data by first author:
final_plot.scatter(godard2010_rates , godard2010_ksn, c = '0', edgecolor='0', marker='+')
final_plot.scatter(harkins2007_rates , harkins2007_ksn, c = '1', edgecolor='0', marker='o')
final_plot.scatter(ouimet2009_rates , ouimet2009_ksn, c = '1', edgecolor='0', marker='s')
final_plot.scatter(godard2012_rates , godard2012_ksn, c = '1', edgecolor='0', marker='D')
final_plot.scatter(finnegan2008_rates , finnegan2008_ksn, c = '1', edgecolor='0', marker='^')
final_plot.scatter(wobus2005_rates , wobus2005_ksn, c = '1', edgecolor='0', marker='*')
final_plot.scatter(scherler2014_rates , scherler2014_ksn, c = '1', edgecolor='0', marker='x')
final_plot.scatter(godard2014_rates , godard2014_ksn, c = '1', edgecolor='0', marker='v')


#plot polishing
final_plot.set_xlim(0,1.5)
final_plot.set_ylim(0,1000)
final_plot.set_xlabel('Erosion rate [mm/yr]')
final_plot.set_ylabel(r'Channel steepness index [m$^{0.9}$]')
final_plot.tick_params(axis='x', pad=10)

#legend
final_plot.legend(loc='upper right', prop={'size':16}, ncol=2)

#export
fig.savefig('shobe_etal_fig10.eps', dpi=1000, bbox_inches='tight')