#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Tue Mar 27 11:04:01 2018

@author: Charlie Shobe, University of Colorado

This script creates Figure 1 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 1 is a conceptual figure comparing two channel reach longitudinal
profiles: one generated without hillslope-derived blocks and one
generated under the influence of blocks.

INPUTS
------
Two .csv files, each of which is a time series of channel elevation 
through time during a 400 ky model run. Each csv loads as a mxn matrix
where m is the number of rows (one row for each time at which elevation was
recorded) and n is the number of columns (one for each channel node).

One time series was generated with gamma = 0 m^(-2), and one with 
gamma = 3 m^(-2). All other parameters were held constant.
"""
from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt
matplotlib.rcParams.update({'font.size': 24})

#user-defined parameters
gamma_0_file = 'shobe_etal_fig1_data_gamma0.csv' #csv file containing profile evolution data
gamma_3_file = 'shobe_etal_fig1_data_gamma3.csv' #csv file containing profile evolution data
shift = 31 #[m], shifting profile elevations so all elevations are positive

#import data from CSV files
gamma_0_data = np.genfromtxt(gamma_0_file, delimiter = ',', skip_header = 0)
gamma_3_data = np.genfromtxt(gamma_3_file, delimiter = ',', skip_header = 0)

#extract gamma=0 final channel profile
gamma_0_400ky = gamma_0_data[400, :] 

#extract gamma=3 final channel profile
gamma_3_400ky = gamma_3_data[400, :]

#set up plotting domain
x_dist = np.arange(0,100,1) * 10

#instantiate figure and subplot structure
norm_profiles = plt.figure(figsize = (10,6))
gamma_plot = plt.subplot()


#plot gamma=3 profile
gamma_plot.plot(x_dist, gamma_3_400ky + shift, linestyle='-', color='k', 
                linewidth=3, zorder = 1, label='Frequent block delivery')


#plot gamma=0 profile
gamma_plot.plot(x_dist, gamma_0_400ky + shift, linestyle='--', color='k', 
                linewidth=3, zorder = 1, label='No block delivery')

#plot settings
gamma_plot.set_xlim([0, 1000])
gamma_plot.set_ylim([0, 20])
gamma_plot.set_xlabel('Distance [m]')
gamma_plot.set_ylabel('Elevation [m]')
gamma_plot.legend(loc='upper right', fontsize = 18)

gamma_plot.text(500, 11, 
                'Block delivery causes steep,\n stepped reach profiles')#, va='center')
gamma_plot.text(10, 1, 
                'Block-free reach profiles\n have low slope, are linear')
gamma_plot.text(10, 10, '$>$2x difference \n in mean slope')

#arrows pointing from text to plotted lines
gamma_plot.annotate(' ', xy=(150, 14.5), xytext=(150, 12.9),
            arrowprops=dict(facecolor='black', shrink=0.05),
            )
gamma_plot.annotate(' ', xy=(150, 6.2), xytext=(150, 9.8),
            arrowprops=dict(facecolor='black', shrink=0.05),
            )

#finally, save the figure
plt.tight_layout()
norm_profiles.savefig('shobe_etal_fig1.eps', dpi=1000)