# -*- coding: utf-8 -*-
"""
Created on Thu Dec  1 11:31:22 2016

@author: Charlie Shobe, University of Colorado

This script creates Figure 2 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 2 plots output from the Morris One-At-A-Time (MOAT) sensitivity 
analysis technique. It consists of eight scatter plots showing the mean and 
standard deviation of the effects of each model parameter on each of eight
model metrics.

INPUTS
------
A single .csv file containing the means and standard deviations returned
by the MOAT analysis for each model parameter for each model metric.
"""
from __future__ import division
import numpy as np
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import matplotlib.pyplot as plt
matplotlib.rcParams.update({'font.size': 24})

#get data
data = np.genfromtxt('shobe_etal_fig2_data.csv', delimiter=',', skip_header = 1)
length_of_dataset = 9
moat_mod_means = data[:, 0]
moat_stdevs = data[:, 1]

#parse data into individual metrics

#total volume lost
total_vol_lost_mean = moat_mod_means[0:9]
total_vol_lost_stdev = moat_stdevs[0:9]
#final max elev
max_elev_mean = moat_mod_means[9:18]
max_elev_stdev = moat_stdevs[9:18]
#final mean elev
mean_elev_mean = moat_mod_means[18:27]
mean_elev_stdev = moat_stdevs[18:27]
#final stdev elev
stdev_elev_mean = moat_mod_means[27:36]
stdev_elev_stdev = moat_stdevs[27:36]
#final max slope
max_slope_mean = moat_mod_means[36:45]
max_slope_stdev = moat_stdevs[36:45]
#final mean slope
mean_slope_mean = moat_mod_means[45:54]
mean_slope_stdev = moat_stdevs[45:54]
#final stdev slope
stdev_slope_mean = moat_mod_means[54:63]
stdev_slope_stdev = moat_stdevs[54:63]
#total blocks
total_blocks_mean = moat_mod_means[63:]
total_blocks_stdev = moat_stdevs[63:]

moat_param_labels = [r'$\gamma$', '$D_0$', '$k_\mathrm{b}$', 
                     '$k_\mathrm{bb}$', '$T_\mathrm{r}$',r'$z_0$',
                     r'$\tau_c$', r'$E$', r'$\tau_{cb}$']
colors = ['maroon','g','b','c','k','gold','indigo','fuchsia', 'orange']

#create 8-panel figure
moat_fig = plt.figure(figsize=(18,36))

###########plot 1 of 8: total volume lost metric
moat_plot1 = plt.subplot(421)
a = moat_plot1.scatter(total_vol_lost_mean[0], total_vol_lost_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot1.scatter(total_vol_lost_mean[1], total_vol_lost_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot1.scatter(total_vol_lost_mean[2], total_vol_lost_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot1.scatter(total_vol_lost_mean[3], total_vol_lost_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot1.scatter(total_vol_lost_mean[4], total_vol_lost_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot1.scatter(total_vol_lost_mean[5], total_vol_lost_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot1.scatter(total_vol_lost_mean[6], total_vol_lost_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot1.scatter(total_vol_lost_mean[7], total_vol_lost_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot1.scatter(total_vol_lost_mean[8], total_vol_lost_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot1.set_xscale('log')
moat_plot1.set_yscale('log')
moat_plot1.set_xlim(5000, 0.1*10**9)
moat_plot1.set_ylim(10000, 3e7)
moat_plot1.set_xlabel(r'Modified mean [-]')
moat_plot1.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot1.spines.itervalues()]
moat_plot1.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(total_vol_lost_mean[0], total_vol_lost_stdev[0]), xytext=(-30, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(total_vol_lost_mean[1], total_vol_lost_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(total_vol_lost_mean[2], total_vol_lost_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(total_vol_lost_mean[3], total_vol_lost_stdev[3]), xytext=(-50, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(total_vol_lost_mean[4], total_vol_lost_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(total_vol_lost_mean[5], total_vol_lost_stdev[5]), xytext=(-32, -7),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(total_vol_lost_mean[6], total_vol_lost_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(total_vol_lost_mean[7], total_vol_lost_stdev[7]), xytext=(20, 15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(total_vol_lost_mean[8], total_vol_lost_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(.8e5, 1.5e4,r'Total volume eroded [m$^3$]')

###########plot 2 of 8: maximum elevation metric
moat_plot2 = plt.subplot(422)
a = moat_plot2.scatter(max_elev_mean[0], max_elev_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot2.scatter(max_elev_mean[1], max_elev_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot2.scatter(max_elev_mean[2], max_elev_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot2.scatter(max_elev_mean[3], max_elev_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot2.scatter(max_elev_mean[4], max_elev_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot2.scatter(max_elev_mean[5], max_elev_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot2.scatter(max_elev_mean[6], max_elev_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot2.scatter(max_elev_mean[7], max_elev_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot2.scatter(max_elev_mean[8], max_elev_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot2.set_xscale('log')
moat_plot2.set_yscale('log')
moat_plot2.set_xlim(.2, 5000)
moat_plot2.set_ylim(.2, 3000)
moat_plot2.set_xlabel(r'Modified mean [-]')
moat_plot2.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot2.spines.itervalues()]
moat_plot2.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(max_elev_mean[0], max_elev_stdev[0]), xytext=(-30, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(max_elev_mean[1], max_elev_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(max_elev_mean[2], max_elev_stdev[2]), xytext=(10, -15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(max_elev_mean[3], max_elev_stdev[3]), xytext=(-50, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(max_elev_mean[4], max_elev_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(max_elev_mean[5], max_elev_stdev[5]), xytext=(0, 35),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(max_elev_mean[6], max_elev_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(max_elev_mean[7], max_elev_stdev[7]), xytext=(0, -15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(max_elev_mean[8], max_elev_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(5, .3,'Final max. elevation [m]')

###########plot 3 of 8: mean elevation metric
moat_plot3 = plt.subplot(423)
a = moat_plot3.scatter(mean_elev_mean[0], mean_elev_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot3.scatter(mean_elev_mean[1], mean_elev_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot3.scatter(mean_elev_mean[2], mean_elev_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot3.scatter(mean_elev_mean[3], mean_elev_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot3.scatter(mean_elev_mean[4], mean_elev_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot3.scatter(mean_elev_mean[5], mean_elev_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot3.scatter(mean_elev_mean[6], mean_elev_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot3.scatter(mean_elev_mean[7], mean_elev_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot3.scatter(mean_elev_mean[8], mean_elev_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot3.set_xscale('log')
moat_plot3.set_yscale('log')
moat_plot3.set_xlim(0.5, 10000)
moat_plot3.set_ylim(1.0, 3000)
moat_plot3.set_xlabel(r'Modified mean [-]')
moat_plot3.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot3.spines.itervalues()]
moat_plot3.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(mean_elev_mean[0], mean_elev_stdev[0]), xytext=(-30, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(mean_elev_mean[1], mean_elev_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(mean_elev_mean[2], mean_elev_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(mean_elev_mean[3], mean_elev_stdev[3]), xytext=(-50, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(mean_elev_mean[4], mean_elev_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(mean_elev_mean[5], mean_elev_stdev[5]), xytext=(-32, 0),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(mean_elev_mean[6], mean_elev_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(mean_elev_mean[7], mean_elev_stdev[7]), xytext=(20, 15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(mean_elev_mean[8], mean_elev_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(10, 1.3,'Final mean elevation [m]')

###########plot 4 of 8: standard deviation of elevation metric
moat_plot4 = plt.subplot(424)
a = moat_plot4.scatter(stdev_elev_mean[0], stdev_elev_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot4.scatter(stdev_elev_mean[1], stdev_elev_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot4.scatter(stdev_elev_mean[2], stdev_elev_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot4.scatter(stdev_elev_mean[3], stdev_elev_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot4.scatter(stdev_elev_mean[4], stdev_elev_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot4.scatter(stdev_elev_mean[5], stdev_elev_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot4.scatter(stdev_elev_mean[6], stdev_elev_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot4.scatter(stdev_elev_mean[7], stdev_elev_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot4.scatter(stdev_elev_mean[8], stdev_elev_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot4.set_xscale('log')
moat_plot4.set_yscale('log')
moat_plot4.set_xlim(0.1, 600)
moat_plot4.set_ylim(0.2, 300)
moat_plot4.set_xlabel(r'Modified mean [-]')
moat_plot4.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot4.spines.itervalues()]
moat_plot4.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(stdev_elev_mean[0], stdev_elev_stdev[0]), xytext=(-30, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(stdev_elev_mean[1], stdev_elev_stdev[1]), xytext=(-33, 43),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(stdev_elev_mean[2], stdev_elev_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(stdev_elev_mean[3], stdev_elev_stdev[3]), xytext=(-50, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(stdev_elev_mean[4], stdev_elev_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(stdev_elev_mean[5], stdev_elev_stdev[5]), xytext=(-35, 5),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(stdev_elev_mean[6], stdev_elev_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(stdev_elev_mean[7], stdev_elev_stdev[7]), xytext=(20, 10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(stdev_elev_mean[8], stdev_elev_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(2, .25,'Final stdev elevation [m]')

###########plot 5 of 8: maximum slope metric
moat_plot5 = plt.subplot(425)
a = moat_plot5.scatter(max_slope_mean[0], max_slope_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot5.scatter(max_slope_mean[1], max_slope_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot5.scatter(max_slope_mean[2], max_slope_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot5.scatter(max_slope_mean[3], max_slope_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot5.scatter(max_slope_mean[4], max_slope_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot5.scatter(max_slope_mean[5], max_slope_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot5.scatter(max_slope_mean[6], max_slope_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot5.scatter(max_slope_mean[7], max_slope_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot5.scatter(max_slope_mean[8], max_slope_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot5.set_xscale('log')
moat_plot5.set_yscale('log')
moat_plot5.set_xlim(0.05, 200)
moat_plot5.set_ylim(0.06, 400)
moat_plot5.set_xlabel(r'Modified mean [-]')
moat_plot5.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot5.spines.itervalues()]
moat_plot5.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(max_slope_mean[0], max_slope_stdev[0]), xytext=(-30, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(max_slope_mean[1], max_slope_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(max_slope_mean[2], max_slope_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(max_slope_mean[3], max_slope_stdev[3]), xytext=(-50, 2),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(max_slope_mean[4], max_slope_stdev[4]), xytext=(-30, 40),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(max_slope_mean[5], max_slope_stdev[5]), xytext=(15, -2),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(max_slope_mean[6], max_slope_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(max_slope_mean[7], max_slope_stdev[7]), xytext=(10, 35),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(max_slope_mean[8], max_slope_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(2, 0.08,'Final max. slope [-]')

###########plot 6 of 8: mean slope metric
moat_plot6 = plt.subplot(426)
a = moat_plot6.scatter(mean_slope_mean[0], mean_slope_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot6.scatter(mean_slope_mean[1], mean_slope_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot6.scatter(mean_slope_mean[2], mean_slope_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot6.scatter(mean_slope_mean[3], mean_slope_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot6.scatter(mean_slope_mean[4], mean_slope_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot6.scatter(mean_slope_mean[5], mean_slope_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot6.scatter(mean_slope_mean[6], mean_slope_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot6.scatter(mean_slope_mean[7], mean_slope_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot6.scatter(mean_slope_mean[8], mean_slope_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot6.set_xscale('log')
moat_plot6.set_yscale('log')
moat_plot6.set_xlim(0.0002, 6)
moat_plot6.set_ylim(0.0005, 3)
moat_plot6.set_xlabel(r'Modified mean [-]')
moat_plot6.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot6.spines.itervalues()]
moat_plot6.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(mean_slope_mean[0], mean_slope_stdev[0]), xytext=(-30, 25),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(mean_slope_mean[1], mean_slope_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(mean_slope_mean[2], mean_slope_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(mean_slope_mean[3], mean_slope_stdev[3]), xytext=(-50, 15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(mean_slope_mean[4], mean_slope_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(mean_slope_mean[5], mean_slope_stdev[5]), xytext=(0, 36),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(mean_slope_mean[6], mean_slope_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(mean_slope_mean[7], mean_slope_stdev[7]), xytext=(18, 15),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(mean_slope_mean[8], mean_slope_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(0.02, 0.0006,'Final mean slope [-]')

###########plot 7 of 8: standard deviation of slope metric
moat_plot7 = plt.subplot(427)
a = moat_plot7.scatter(stdev_slope_mean[0], stdev_slope_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot7.scatter(stdev_slope_mean[1], stdev_slope_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot7.scatter(stdev_slope_mean[2], stdev_slope_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot7.scatter(stdev_slope_mean[3], stdev_slope_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot7.scatter(stdev_slope_mean[4], stdev_slope_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot7.scatter(stdev_slope_mean[5], stdev_slope_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot7.scatter(stdev_slope_mean[6], stdev_slope_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot7.scatter(stdev_slope_mean[7], stdev_slope_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot7.scatter(stdev_slope_mean[8], stdev_slope_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot7.set_xscale('log')
moat_plot7.set_yscale('log')
moat_plot7.set_xlim(0.004, 30)
moat_plot7.set_ylim(0.006, 30)
moat_plot7.set_xlabel(r'Modified mean [-]')
moat_plot7.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot7.spines.itervalues()]
moat_plot7.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(stdev_slope_mean[0], stdev_slope_stdev[0]), xytext=(-28, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(stdev_slope_mean[1], stdev_slope_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(stdev_slope_mean[2], stdev_slope_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(stdev_slope_mean[3], stdev_slope_stdev[3]), xytext=(-50, 10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(stdev_slope_mean[4], stdev_slope_stdev[4]), xytext=(-33, 35),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(stdev_slope_mean[5], stdev_slope_stdev[5]), xytext=(15, 0),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(stdev_slope_mean[6], stdev_slope_stdev[6]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(stdev_slope_mean[7], stdev_slope_stdev[7]), xytext=(20, 20),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(stdev_slope_mean[8], stdev_slope_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(0.12, 0.008,'Final stdev slope [-]')

###########plot 8 of 8: total blocks delivered metric
moat_plot8 = plt.subplot(428)
a = moat_plot8.scatter(total_blocks_mean[0], total_blocks_stdev[0], s = 800, c = colors[0], alpha=0.7)
b = moat_plot8.scatter(total_blocks_mean[1], total_blocks_stdev[1], s = 800, c = colors[1], alpha=0.7)
c = moat_plot8.scatter(total_blocks_mean[2], total_blocks_stdev[2], s = 800, c = colors[2], alpha=0.7)
d = moat_plot8.scatter(total_blocks_mean[3], total_blocks_stdev[3], s = 800, c = colors[3], alpha=0.7)
e = moat_plot8.scatter(total_blocks_mean[4], total_blocks_stdev[4], s = 800, c = colors[4], alpha=0.7)
f = moat_plot8.scatter(total_blocks_mean[5], total_blocks_stdev[5], s = 800, c = colors[5], alpha=0.7)
g = moat_plot8.scatter(total_blocks_mean[6], total_blocks_stdev[6], s = 800, c = colors[6], alpha=0.7)
h = moat_plot8.scatter(total_blocks_mean[7], total_blocks_stdev[7], s = 800, c = colors[7], alpha=0.7)
i = moat_plot8.scatter(total_blocks_mean[8], total_blocks_stdev[8], s = 800, c = colors[8], alpha=0.7)

moat_plot8.set_xscale('log')
moat_plot8.set_yscale('log')
moat_plot8.set_xlim(800, 5*10**5)
moat_plot8.set_ylim(1000, 1*10**6)
moat_plot8.set_xlabel(r'Modified mean [-]')
moat_plot8.set_ylabel(r'Standard deviation [-]')
[i.set_linewidth(1.5) for j in moat_plot8.spines.itervalues()]
moat_plot8.tick_params(width=1.5)

##annotate labels for points
plt.annotate(moat_param_labels[0],
    xy=(total_blocks_mean[0], total_blocks_stdev[0]), xytext=(7, 30),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[1],
    xy=(total_blocks_mean[1], total_blocks_stdev[1]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[2],
    xy=(total_blocks_mean[2], total_blocks_stdev[2]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[3],
    xy=(total_blocks_mean[3], total_blocks_stdev[3]), xytext=(-50, 5),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[4],
    xy=(total_blocks_mean[4], total_blocks_stdev[4]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[5],
    xy=(total_blocks_mean[5], total_blocks_stdev[5]), xytext=(-32, 33),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[6],
    xy=(total_blocks_mean[6], total_blocks_stdev[6]), xytext=(15, 0),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[7],
    xy=(total_blocks_mean[7], total_blocks_stdev[7]), xytext=(-35, -10),
    textcoords='offset points', ha='left', va='top')
plt.annotate(moat_param_labels[8],
    xy=(total_blocks_mean[8], total_blocks_stdev[8]), xytext=(15, -10),
    textcoords='offset points', ha='left', va='top')

plt.text(.6e4, 1.2e3,r'Total blocks delivered [\#]')

#save figure
moat_fig.savefig('shobe_etal_fig2.eps', dpi=1000)