#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Sun Mar  4 21:41:52 2018

@author: Charlie Shobe, University of Colorado

This script creates Figure 3 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 3 plots erosion rate vs. slope for four different values of discharge
variability (c=1.5, c=1.0, c=0.5, c=0.25). The plots show model results from
the BRaKE (Blocky River and Knickpoint Evolution) model.

INPUTS
------
Four .csv files, each containing the output from a set of model runs. The
csv files include both the model parameter values and the model metrics
returned. Each row in each csv is a single model run.

"""
from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt

#data files
upper_left_data = 'shobe_etal_fig3a_data.csv'
upper_right_data = 'shobe_etal_fig3b_data.csv'
lower_left_data = 'shobe_etal_fig3c_data.csv'
lower_right_data = 'shobe_etal_fig3d_data.csv'

#import and parse data
data = np.genfromtxt(upper_left_data, delimiter = ',', skip_header = 1)
length_of_series = 75 #number of entries for a given gamma
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh = data[(length_of_series * 9):, 15]

#plotting parameter
matplotlib.rcParams.update({'font.size': 20})

#instantiate plot
e_vs_s = plt.figure(figsize=(16,8))

##########FIRST SUBPLOT, C = 1.5
e_vs_s_plot1 = plt.subplot(231)

e_vs_s_plot1.plot(bl_lower_rate, gamma_zero_slope, c = 'k', clip_on=False, linewidth = 2, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot1.plot(bl_lower_rate, gamma_tenth_slope, color=plt.cm.jet(0.1), clip_on=False, linewidth = 2, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot1.plot(bl_lower_rate, gamma_twotenths_slope, color=plt.cm.jet(0.2), clip_on=False, linewidth = 2, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot1.plot(bl_lower_rate, gamma_half_slope, color=plt.cm.jet(0.3), clip_on=False, linewidth = 2, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot1.plot(bl_lower_rate, gamma_one_slope, color=plt.cm.jet(0.4), clip_on=False, linewidth = 2, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot1.plot(bl_lower_rate, gamma_two_slope, color=plt.cm.jet(0.5), clip_on=False, linewidth = 2, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot1.plot(bl_lower_rate, gamma_three_slope, color=plt.cm.jet(0.6), clip_on=False, linewidth = 2, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot1.plot(bl_lower_rate, gamma_four_slope, color=plt.cm.jet(0.7), clip_on=False, linewidth = 2, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot1.plot(bl_lower_rate, gamma_five_slope, color=plt.cm.jet(0.8), clip_on=False, linewidth = 2, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot1.plot(bl_lower_rate, const_thresh, color='k', clip_on=False, linestyle=':',linewidth = 2, label = r'$\tau_c=100$ Pa', zorder=11)

e_vs_s_plot1.set_xscale('log')
e_vs_s_plot1.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1026x^{1.3655}$, $R^2=0.99$')

e_vs_s_plot1.set_xlim([0.00001, .005])
e_vs_s_plot1.set_ylim([0.0001, 2])

############SECOND SUBPLOT, C = 1.0
data = np.genfromtxt(upper_right_data, delimiter = ',', skip_header = 1)
length_of_series = 75 #number of entries for a given gamma
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh = data[(length_of_series * 9):, 15]

#plotting
matplotlib.rcParams.update({'font.size': 20})

e_vs_s_plot2 = plt.subplot(232)

e_vs_s_plot2.plot(bl_lower_rate, gamma_zero_slope, c = 'k', clip_on=False, linewidth = 2, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot2.plot(bl_lower_rate, gamma_tenth_slope, color=plt.cm.jet(0.1), clip_on=False, linewidth = 2, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot2.plot(bl_lower_rate, gamma_twotenths_slope, color=plt.cm.jet(0.2), clip_on=False, linewidth = 2, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot2.plot(bl_lower_rate, gamma_half_slope, color=plt.cm.jet(0.3), clip_on=False, linewidth = 2, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot2.plot(bl_lower_rate, gamma_one_slope, color=plt.cm.jet(0.4), clip_on=False, linewidth = 2, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot2.plot(bl_lower_rate, gamma_two_slope, color=plt.cm.jet(0.5), clip_on=False, linewidth = 2, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot2.plot(bl_lower_rate, gamma_three_slope, color=plt.cm.jet(0.6), clip_on=False, linewidth = 2, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot2.plot(bl_lower_rate, gamma_four_slope, color=plt.cm.jet(0.7), clip_on=False, linewidth = 2, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot2.plot(bl_lower_rate, gamma_five_slope, color=plt.cm.jet(0.8), clip_on=False, linewidth = 2, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot2.plot(bl_lower_rate, const_thresh, color='k', clip_on=False, linestyle=':',linewidth = 2, label = r'$\tau_c=100$ Pa', zorder=11)

e_vs_s_plot2.set_xscale('log')
e_vs_s_plot2.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1103x^{1.3658}$, $R^2=0.99$')

e_vs_s_plot2.set_xlim([0.00001, .005])
e_vs_s_plot2.set_ylim([0.0001, 2])

###########THIRD SUBPLOT, C = 0.5
data = np.genfromtxt(lower_left_data, delimiter = ',', skip_header = 1)
length_of_series = 75 #number of entries for a given gamma
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh = data[(length_of_series * 9):, 15]

#plotting
e_vs_s_plot3 = plt.subplot(234)

e_vs_s_plot3.plot(bl_lower_rate, gamma_zero_slope, c = 'k', clip_on=False, linewidth = 2, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot3.plot(bl_lower_rate, gamma_tenth_slope, color=plt.cm.jet(0.1), clip_on=False, linewidth = 2, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot3.plot(bl_lower_rate, gamma_twotenths_slope, color=plt.cm.jet(0.2), clip_on=False, linewidth = 2, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot3.plot(bl_lower_rate, gamma_half_slope, color=plt.cm.jet(0.3), clip_on=False, linewidth = 2, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot3.plot(bl_lower_rate, gamma_one_slope, color=plt.cm.jet(0.4), clip_on=False, linewidth = 2, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot3.plot(bl_lower_rate, gamma_two_slope, color=plt.cm.jet(0.5), clip_on=False, linewidth = 2, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot3.plot(bl_lower_rate, gamma_three_slope, color=plt.cm.jet(0.6), clip_on=False, linewidth = 2, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot3.plot(bl_lower_rate, gamma_four_slope, color=plt.cm.jet(0.7), clip_on=False, linewidth = 2, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot3.plot(bl_lower_rate, gamma_five_slope, color=plt.cm.jet(0.8), clip_on=False, linewidth = 2, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot3.plot(bl_lower_rate, const_thresh, color='k', clip_on=False, linestyle=':',linewidth = 2, label = r'$\tau_c=100$ Pa', zorder=11)

e_vs_s_plot3.set_xscale('log')
e_vs_s_plot3.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1437x^{1.3648}$, $R^2=0.99$')

e_vs_s_plot3.set_xlabel('Erosion rate [m/yr]')

e_vs_s_plot3.set_xlim([0.00001, .005])
e_vs_s_plot3.set_ylim([0.0001, 2])

##########FOURTH SUBPLOT, C = 0.25
data = np.genfromtxt(lower_right_data, delimiter = ',', skip_header = 1)
length_of_series = 75 #number of entries for a given gamma
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh = data[(length_of_series * 9):, 15]

#plotting
e_vs_s_plot4 = plt.subplot(235)

e_vs_s_plot4.plot(bl_lower_rate, gamma_zero_slope, c = 'k', clip_on=False, linewidth = 2, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot4.plot(bl_lower_rate, gamma_tenth_slope, color=plt.cm.jet(0.1), clip_on=False, linewidth = 2, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot4.plot(bl_lower_rate, gamma_twotenths_slope, color=plt.cm.jet(0.2), clip_on=False, linewidth = 2, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot4.plot(bl_lower_rate, gamma_half_slope, color=plt.cm.jet(0.3), clip_on=False, linewidth = 2, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot4.plot(bl_lower_rate, gamma_one_slope, color=plt.cm.jet(0.4), clip_on=False, linewidth = 2, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot4.plot(bl_lower_rate, gamma_two_slope, color=plt.cm.jet(0.5), clip_on=False, linewidth = 2, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot4.plot(bl_lower_rate, gamma_three_slope, color=plt.cm.jet(0.6), clip_on=False, linewidth = 2, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot4.plot(bl_lower_rate, gamma_four_slope, color=plt.cm.jet(0.7), clip_on=False, linewidth = 2, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot4.plot(bl_lower_rate, gamma_five_slope, color=plt.cm.jet(0.8), clip_on=False, linewidth = 2, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot4.plot(bl_lower_rate, const_thresh, color='k', clip_on=False, linestyle=':',linewidth = 2, label = r'$\tau_c=100$ Pa', zorder=11)

e_vs_s_plot4.set_xscale('log')
e_vs_s_plot4.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=2590x^{1.3548}$, $R^2=0.99$')

e_vs_s_plot4.set_xlabel('Erosion rate [m/yr]')

e_vs_s_plot4.set_xlim([0.00001, .005])
e_vs_s_plot4.set_ylim([0.0001, 2])

# Put a legend to the right of the current axis
handles, labels = e_vs_s_plot4.get_legend_handles_labels()
e_vs_s_plot4.legend(handles[::-1], labels[::-1], loc='center left', scatterpoints = 1, fontsize = 14, bbox_to_anchor=(1.05, 1))

#########################polish figure:
#text labeling panels
e_vs_s.text(0.075, 0.86, 'A: $c = 1.5$, $\overline{Q} = 15$ m$^3$/s \n Low discharge variability')
e_vs_s.text(0.39, 0.89, 'B: $c = 1.0$, $\overline{Q} = 15$ m$^3$/s')
e_vs_s.text(0.075, 0.485, 'C: $c = 0.5$, $\overline{Q} = 15$ m$^3$/s')
e_vs_s.text(0.39, 0.45, 'D: $c = 0.25$, $\overline{Q} = 15$ m$^3$/s \n High discharge variability')

#label y-axes all at once
e_vs_s.text(0.0, 0.55, 'Steady-state mean slope [-]', va='center', rotation='vertical')

#turn off ticks on x-axis for upper plots
e_vs_s_plot1.axes.xaxis.set_ticklabels([])
e_vs_s_plot2.axes.xaxis.set_ticklabels([])

#turn off ticks on y-axis for plots 2 and 4 (right side)
e_vs_s_plot2.axes.yaxis.set_ticklabels([])
e_vs_s_plot4.axes.yaxis.set_ticklabels([])

#annotate top left panel with arrow showing transition zone
e_vs_s_plot1.annotate(' ', xy=(0.0016, 0.6), xytext=(0.001, 1.6),
            arrowprops=dict(facecolor='black', shrink=0.05),
            )

#save figure
plt.tight_layout(pad=1.5, h_pad=0, w_pad=0)
e_vs_s.savefig('shobe_etal_fig3.eps', dpi=1000, bbox_inches='tight')