#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Mon Mar  5 11:55:43 2018

@author: Charlie Shobe, University of Colorado

This script creates Figure 4 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 4 plots erosion rate vs. slope for four different values of mean 
discharge (10, 15, 20, 30 m^3/s). The plots show model results from
the BRaKE (Blocky River and Knickpoint Evolution) model.
INPUTS
------
Four .csv files, each containing the output from a set of model runs. The
csv files include both the model parameter values and the model metrics
returned. Each row in each csv is a single model run.
"""

from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt

#data files
upper_left_data = 'shobe_etal_fig4a_data.csv'
upper_right_data = 'shobe_etal_fig4b_data.csv'
lower_left_data = 'shobe_etal_fig4c_data.csv'
lower_right_data = 'shobe_etal_fig4d_data.csv'

#import and parse data
length_of_series = 75 #number of entries for a given gamma

#data for mean q = 10 m3/s
data1 = np.genfromtxt(upper_left_data, delimiter = ',', skip_header = 1)
bl_lower_rate = data1[0:length_of_series, 9]

gamma_zero_slope_mean10 = data1[0:length_of_series, 15]
gamma_tenth_slope_mean10 = data1[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope_mean10 = data1[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope_mean10 = data1[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope_mean10 = data1[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope_mean10 = data1[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope_mean10 = data1[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope_mean10 = data1[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope_mean10 = data1[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_mean10 = data1[(9 * length_of_series):, 15]

#data for mean q = 15 m3/s
data2 = np.genfromtxt(upper_right_data, delimiter = ',', skip_header = 1)
gamma_zero_slope_mean15 = data2[0:length_of_series, 15]
gamma_tenth_slope_mean15 = data2[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope_mean15 = data2[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope_mean15 = data2[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope_mean15 = data2[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope_mean15 = data2[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope_mean15 = data2[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope_mean15 = data2[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope_mean15 = data2[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_mean15 = data2[(9 * length_of_series):, 15]

#data for mean q = 20 m3/s
data3 = np.genfromtxt(lower_left_data, delimiter = ',', skip_header = 1)
gamma_zero_slope_mean20 = data3[0:length_of_series, 15]
gamma_tenth_slope_mean20 = data3[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope_mean20 = data3[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope_mean20 = data3[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope_mean20 = data3[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope_mean20 = data3[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope_mean20 = data3[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope_mean20 = data3[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope_mean20 = data3[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_mean20 = data3[(9 * length_of_series):, 15]

#data for mean q = 30 m3/s
data4 = np.genfromtxt(lower_right_data, delimiter = ',', skip_header = 1)
gamma_zero_slope_mean30 = data4[0:length_of_series, 15]
gamma_tenth_slope_mean30 = data4[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope_mean30 = data4[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope_mean30 = data4[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope_mean30 = data4[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope_mean30 = data4[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope_mean30 = data4[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope_mean30 = data4[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope_mean30 = data4[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_mean30 = data4[(9 * length_of_series):, 15]

#set plot font size parameter
matplotlib.rcParams.update({'font.size': 20})

#instantiate plot
e_vs_s = plt.figure(figsize=(16,8))

##########UPPER LEFT SUBPLOT, MEAN Q = 10 M3/S
e_vs_s_plot1 = plt.subplot(231)

e_vs_s_plot1.plot(bl_lower_rate, gamma_zero_slope_mean10, c = 'k', linewidth=2, clip_on=False, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot1.plot(bl_lower_rate, gamma_tenth_slope_mean10, color=plt.cm.jet(0.1), linewidth=2, clip_on=False, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot1.plot(bl_lower_rate, gamma_twotenths_slope_mean10, color=plt.cm.jet(0.2), linewidth=2, clip_on=False, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot1.plot(bl_lower_rate, gamma_half_slope_mean10, color=plt.cm.jet(0.3), linewidth=2, clip_on=False, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot1.plot(bl_lower_rate, gamma_one_slope_mean10, color=plt.cm.jet(0.4), linewidth=2, clip_on=False, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot1.plot(bl_lower_rate, gamma_two_slope_mean10, color=plt.cm.jet(0.5), linewidth=2, clip_on=False, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot1.plot(bl_lower_rate, gamma_three_slope_mean10, color=plt.cm.jet(0.6), linewidth=2, clip_on=False, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot1.plot(bl_lower_rate, gamma_four_slope_mean10, color=plt.cm.jet(0.7), linewidth=2, clip_on=False, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot1.plot(bl_lower_rate, gamma_five_slope_mean10, color=plt.cm.jet(0.8), linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot1.plot(bl_lower_rate, const_thresh_mean10, color='k', linestyle=':', linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=11)

e_vs_s_plot1.set_xscale('log')
e_vs_s_plot1.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1667x^{1.3477}$, $R^2=0.99$')

e_vs_s_plot1.set_xlim([0.00001, .005])
e_vs_s_plot1.set_ylim([0.0001, 2])

############UPPER RIGHT SUBPLOT, MEAN Q = 15 M3/S

e_vs_s_plot2 = plt.subplot(232)

e_vs_s_plot2.plot(bl_lower_rate, gamma_zero_slope_mean15, c = 'k', linewidth=2, clip_on=False, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot2.plot(bl_lower_rate, gamma_tenth_slope_mean15, color=plt.cm.jet(0.1), linewidth=2, clip_on=False, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot2.plot(bl_lower_rate, gamma_twotenths_slope_mean15, color=plt.cm.jet(0.2), linewidth=2, clip_on=False, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot2.plot(bl_lower_rate, gamma_half_slope_mean15, color=plt.cm.jet(0.3), linewidth=2, clip_on=False, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot2.plot(bl_lower_rate, gamma_one_slope_mean15, color=plt.cm.jet(0.4), linewidth=2, clip_on=False, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot2.plot(bl_lower_rate, gamma_two_slope_mean15, color=plt.cm.jet(0.5), linewidth=2, clip_on=False, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot2.plot(bl_lower_rate, gamma_three_slope_mean15, color=plt.cm.jet(0.6), linewidth=2, clip_on=False, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot2.plot(bl_lower_rate, gamma_four_slope_mean15, color=plt.cm.jet(0.7), linewidth=2, clip_on=False, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot2.plot(bl_lower_rate, gamma_five_slope_mean15, color=plt.cm.jet(0.8), linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot2.plot(bl_lower_rate, const_thresh_mean15, color='k', linestyle=':', linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=11)

e_vs_s_plot2.set_xscale('log')
e_vs_s_plot2.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1437x^{1.3648}$, $R^2=0.99$')

e_vs_s_plot2.set_xlim([0.00001, .005])
e_vs_s_plot2.set_ylim([0.0001, 2])

###########LOWER LEFT SUBPLOT, MEAN Q = 20 M3/S

e_vs_s_plot3 = plt.subplot(234)

e_vs_s_plot3.plot(bl_lower_rate, gamma_zero_slope_mean20, c = 'k', linewidth=2, clip_on=False, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot3.plot(bl_lower_rate, gamma_tenth_slope_mean20, color=plt.cm.jet(0.1), linewidth=2, clip_on=False, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot3.plot(bl_lower_rate, gamma_twotenths_slope_mean20, color=plt.cm.jet(0.2), linewidth=2, clip_on=False, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot3.plot(bl_lower_rate, gamma_half_slope_mean20, color=plt.cm.jet(0.3), linewidth=2, clip_on=False, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot3.plot(bl_lower_rate, gamma_one_slope_mean20, color=plt.cm.jet(0.4), linewidth=2, clip_on=False, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot3.plot(bl_lower_rate, gamma_two_slope_mean20, color=plt.cm.jet(0.5), linewidth=2, clip_on=False, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot3.plot(bl_lower_rate, gamma_three_slope_mean20, color=plt.cm.jet(0.6), linewidth=2, clip_on=False, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot3.plot(bl_lower_rate, gamma_four_slope_mean20, color=plt.cm.jet(0.7), linewidth=2, clip_on=False, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot3.plot(bl_lower_rate, gamma_five_slope_mean20, color=plt.cm.jet(0.8), linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot3.plot(bl_lower_rate, const_thresh_mean20, color='k', linestyle=':', linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=11)

e_vs_s_plot3.set_xscale('log')
e_vs_s_plot3.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1282x^{1.3767}$, $R^2=0.99$')

e_vs_s_plot3.set_xlabel('Erosion rate [m/yr]')

e_vs_s_plot3.set_xlim([0.00001, .005])
e_vs_s_plot3.set_ylim([0.0001, 2])

##########LOWER RIGHT SUBPLOT, MEAN Q = 30 M3/S
e_vs_s_plot4 = plt.subplot(235)

e_vs_s_plot4.plot(bl_lower_rate, gamma_zero_slope_mean30, c = 'k', clip_on=False, linewidth=2, label = r'$\gamma=0$ m$^{-2}$', zorder=2)
e_vs_s_plot4.plot(bl_lower_rate, gamma_tenth_slope_mean30, color=plt.cm.jet(0.1), clip_on=False, linewidth=2, label = r'$\gamma=0.1$ m$^{-2}$', zorder=3)
e_vs_s_plot4.plot(bl_lower_rate, gamma_twotenths_slope_mean30, color=plt.cm.jet(0.2), clip_on=False, linewidth=2, label = r'$\gamma=0.2$ m$^{-2}$', zorder=4)
e_vs_s_plot4.plot(bl_lower_rate, gamma_half_slope_mean30, color=plt.cm.jet(0.3), clip_on=False, linewidth=2, label = r'$\gamma=0.5$ m$^{-2}$', zorder=5)
e_vs_s_plot4.plot(bl_lower_rate, gamma_one_slope_mean30, color=plt.cm.jet(0.4), clip_on=False, linewidth=2, label = r'$\gamma=1$ m$^{-2}$', zorder=6)
e_vs_s_plot4.plot(bl_lower_rate, gamma_two_slope_mean30, color=plt.cm.jet(0.5), clip_on=False, linewidth=2, label = r'$\gamma=2$ m$^{-2}$', zorder=7)
e_vs_s_plot4.plot(bl_lower_rate, gamma_three_slope_mean30, color=plt.cm.jet(0.6), linewidth=2, clip_on=False, label = r'$\gamma=3$ m$^{-2}$', zorder=8)
e_vs_s_plot4.plot(bl_lower_rate, gamma_four_slope_mean30, color=plt.cm.jet(0.7), linewidth=2, clip_on=False, label = r'$\gamma=4$ m$^{-2}$', zorder=9)
e_vs_s_plot4.plot(bl_lower_rate, gamma_five_slope_mean30, color=plt.cm.jet(0.8), linewidth=2, clip_on=False, label = r'$\gamma=5$ m$^{-2}$', zorder=10)
e_vs_s_plot4.plot(bl_lower_rate, const_thresh_mean30, color='k', linestyle=':', linewidth=2, clip_on=False, label = r'$\tau_c=100$ Pa', zorder=11)

e_vs_s_plot4.set_xscale('log')
e_vs_s_plot4.set_yscale('log')
plt.text(.5e-4, 2e-4, r'$y=1049x^{1.3899}$, $R^2=0.99$')

e_vs_s_plot4.set_xlabel('Erosion rate [m/yr]')

e_vs_s_plot4.set_xlim([0.00001, .005])
e_vs_s_plot4.set_ylim([0.0001, 2])

# Put a legend to the right of the current axis
handles, labels = e_vs_s_plot4.get_legend_handles_labels()
e_vs_s_plot4.legend(handles[::-1], labels[::-1], loc='center left', scatterpoints = 1, fontsize = 14, bbox_to_anchor=(1.05, 1))

#########################polish figure:
#text labeling panels
e_vs_s.text(0.075, 0.9, 'A: $\overline{Q} = 10$ m$^3$/s, $c=0.5$')
e_vs_s.text(0.39, 0.86, 'B: $\overline{Q} = 15$ m$^3$/s, $c=0.5$\n Same as Fig. 3c')
e_vs_s.text(0.075, 0.49, 'C: $\overline{Q} = 20$ m$^3$/s, $c=0.5$')
e_vs_s.text(0.39, 0.49, 'D: $\overline{Q} = 30$ m$^3$/s, $c=0.5$')

#label y-axes all at once
e_vs_s.text(0.0, 0.55, 'Steady-state mean slope [-]', va='center', rotation='vertical')

#turn off ticks on x-axis for upper plots
e_vs_s_plot1.axes.xaxis.set_ticklabels([])
e_vs_s_plot2.axes.xaxis.set_ticklabels([])

#turn off ticks on y-axis for plots 2 and 4 (right side)
e_vs_s_plot2.axes.yaxis.set_ticklabels([])
e_vs_s_plot4.axes.yaxis.set_ticklabels([])

#annotate top left panel with arrow showing transition zone
e_vs_s_plot1.annotate(' ', xy=(0.0013, 0.5), xytext=(0.001, 1.6),
            arrowprops=dict(facecolor='black', shrink=0.05),
            )

#final stuff
plt.tight_layout(pad=1.5, h_pad=0, w_pad=0)
e_vs_s.savefig('shobe_etal_fig4.eps', dpi=1000, bbox_inches='tight')