 #!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Tue Mar  6 09:57:11 2018

@author: Charlie Shobe, University of Colorado

This script creates Figure 6 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy, SciPy, and Matplotlib.

Figure 6 plots erosion rate vs. topographic exponent phi for four different 
values of mean discharge (10, 15, 20, 30 m^3/s). The plots show 
model results from the BRaKE (Blocky River and Knickpoint Evolution) model.
Phi is calculated by fitting a line segment to a moving window of points.

INPUTS
------
Four .csv files, each containing the output from a set of model runs. The
csv files include both the model parameter values and the model metrics
returned. Each row in each csv is a single model run.

"""
from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt

#set font size parameter for plots
matplotlib.rcParams.update({'font.size': 20})

#define curve fitting function
from scipy.optimize import curve_fit
def f(x, A, B): 
    return A * x + B

#how many points (in either direction) to center difference over?
n_points_oneway = 5

#define data sources
upper_left_data = 'shobe_etal_fig6a_data.csv'
upper_right_data = 'shobe_etal_fig6b_data.csv'
lower_left_data = 'shobe_etal_fig6c_data.csv'
lower_right_data = 'shobe_etal_fig6d_data.csv'

#instantiate figure
e_vs_phi = plt.figure(figsize=(16,8))

############UPPER LEFT SUBPLOT, MEAN Q=10 M3/S
e_vs_phi_plot1 = plt.subplot(231)

data = np.genfromtxt(upper_left_data, delimiter = ',', skip_header = 1)
length_of_series = 75 #number of entries for a given gamma
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_slope = data[(9 * length_of_series):, 15]

#calculate phi values by linear regression on a moving window
gamma_zero_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_zero_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_zero_phi[i-n_points_oneway] = phi
    
gamma_tenth_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_tenth_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_tenth_phi[i-n_points_oneway] = phi
    
gamma_twotenths_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_twotenths_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_twotenths_phi[i-n_points_oneway] = phi   
    
gamma_half_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_half_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_half_phi[i-n_points_oneway] = phi    
    
gamma_one_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_one_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_one_phi[i-n_points_oneway] = phi    
    
gamma_two_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_two_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_two_phi[i-n_points_oneway] = phi    
    
gamma_three_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_three_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_three_phi[i-n_points_oneway] = phi 
    
gamma_four_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_four_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_four_phi[i-n_points_oneway] = phi   
    
gamma_five_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_five_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_five_phi[i-n_points_oneway] = phi
    
const_thresh_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(const_thresh_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    const_thresh_phi[i-n_points_oneway] = phi

e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_zero_phi, color = 'k', linewidth=2, clip_on=True, label = r'$\gamma=0$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_tenth_phi, color = plt.cm.jet(0.1), linewidth=2, clip_on=True, label = r'$\gamma=0.1$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_twotenths_phi, color = plt.cm.jet(0.2), linewidth=2, clip_on=True, label = r'$\gamma=0.2$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_half_phi, color = plt.cm.jet(0.3), linewidth=2, clip_on=True, label = r'$\gamma=0.5$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_one_phi, color = plt.cm.jet(0.4), linewidth=2, clip_on=True, label = r'$\gamma=1$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_two_phi, color = plt.cm.jet(0.5), linewidth=2, clip_on=True, label = r'$\gamma=2$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_three_phi, color = plt.cm.jet(0.6), linewidth=2, clip_on=True, label = r'$\gamma=3$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_four_phi, color = plt.cm.jet(0.7), linewidth=2, clip_on=True, label = r'$\gamma=4$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_five_phi, color = plt.cm.jet(0.8), linewidth=2, clip_on=True, label = r'$\gamma=5$ m$^{-2}$')
e_vs_phi_plot1.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], const_thresh_phi, color = 'k', linewidth=2, linestyle=':', clip_on=True, label = r'$\tau_c=100$ Pa')

e_vs_phi_plot1.set_xscale('log')

e_vs_phi_plot1.set_ylabel(r'Steady-state $\phi$ [-]')

e_vs_phi_plot1.set_xlim([0.00001, 0.005])
e_vs_phi_plot1.set_ylim([0., 2])

############UPPER RIGHT SUBPLOT, MEAN Q=15 M3/S
e_vs_phi_plot2 = plt.subplot(232)

data = np.genfromtxt(upper_right_data, delimiter = ',', skip_header = 1)
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_slope = data[(9 * length_of_series):, 15]

#calculate phi values by linear regression on a moving window
gamma_zero_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_zero_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_zero_phi[i-n_points_oneway] = phi
    
gamma_tenth_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_tenth_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_tenth_phi[i-n_points_oneway] = phi
    
gamma_twotenths_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_twotenths_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_twotenths_phi[i-n_points_oneway] = phi

gamma_half_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_half_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_half_phi[i-n_points_oneway] = phi
    
gamma_one_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_one_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_one_phi[i-n_points_oneway] = phi
    
gamma_two_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_two_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_two_phi[i-n_points_oneway] = phi
    
gamma_three_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_three_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_three_phi[i-n_points_oneway] = phi
    
gamma_four_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_four_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_four_phi[i-n_points_oneway] = phi
    
gamma_five_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_five_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_five_phi[i-n_points_oneway] = phi
    
const_thresh_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(const_thresh_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    const_thresh_phi[i-n_points_oneway] = phi

e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_zero_phi, color = 'k', linewidth=2, clip_on=True, label = r'$\gamma=0$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_tenth_phi, color = plt.cm.jet(0.1), linewidth=2, clip_on=True, label = r'$\gamma=0.1$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_twotenths_phi, color = plt.cm.jet(0.2), linewidth=2, clip_on=True, label = r'$\gamma=0.2$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_half_phi, color = plt.cm.jet(0.3), linewidth=2, clip_on=True, label = r'$\gamma=0.5$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_one_phi, color = plt.cm.jet(0.4), linewidth=2, clip_on=True, label = r'$\gamma=1$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_two_phi, color = plt.cm.jet(0.5), linewidth=2, clip_on=True, label = r'$\gamma=2$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_three_phi, color = plt.cm.jet(0.6), linewidth=2, clip_on=True, label = r'$\gamma=3$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_four_phi, color = plt.cm.jet(0.7), linewidth=2, clip_on=True, label = r'$\gamma=4$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_five_phi, color = plt.cm.jet(0.8), linewidth=2, clip_on=True, label = r'$\gamma=5$ m$^{-2}$')
e_vs_phi_plot2.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], const_thresh_phi, color = 'k', linewidth=2, linestyle=':', clip_on=True, label = r'$\tau_c=100$ Pa')

e_vs_phi_plot2.set_xscale('log')

e_vs_phi_plot2.set_xlim([0.00001, 0.005])
e_vs_phi_plot2.set_ylim([0., 2])

############LOWER LEFT SUBPLOT, MEAN Q=20 M3/S
e_vs_phi_plot3 = plt.subplot(234)

data = np.genfromtxt(lower_left_data, delimiter = ',', skip_header = 1)
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_slope = data[(9 * length_of_series):, 15]

#calculate phi values by linear regression on a moving window
gamma_zero_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_zero_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_zero_phi[i-n_points_oneway] = phi
    
gamma_tenth_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_tenth_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_tenth_phi[i-n_points_oneway] = phi
    
gamma_twotenths_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_twotenths_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_twotenths_phi[i-n_points_oneway] = phi 
    
gamma_half_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_half_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_half_phi[i-n_points_oneway] = phi
    
gamma_one_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_one_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_one_phi[i-n_points_oneway] = phi 
    
gamma_two_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_two_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_two_phi[i-n_points_oneway] = phi
    
gamma_three_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_three_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_three_phi[i-n_points_oneway] = phi
    
gamma_four_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_four_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_four_phi[i-n_points_oneway] = phi
    
gamma_five_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_five_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_five_phi[i-n_points_oneway] = phi

const_thresh_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(const_thresh_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    const_thresh_phi[i-n_points_oneway] = phi

e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_zero_phi, color = 'k', linewidth=2, clip_on=True, label = r'$\gamma=0$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_tenth_phi, color = plt.cm.jet(0.1), linewidth=2, clip_on=True, label = r'$\gamma=0.1$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_twotenths_phi, color = plt.cm.jet(0.2), linewidth=2, clip_on=True, label = r'$\gamma=0.2$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_half_phi, color = plt.cm.jet(0.3), linewidth=2, clip_on=True, label = r'$\gamma=0.5$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_one_phi, color = plt.cm.jet(0.4), linewidth=2, clip_on=True, label = r'$\gamma=1$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_two_phi, color = plt.cm.jet(0.5), linewidth=2, clip_on=True, label = r'$\gamma=2$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_three_phi, color = plt.cm.jet(0.6), linewidth=2, clip_on=True, label = r'$\gamma=3$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_four_phi, color = plt.cm.jet(0.7), linewidth=2, clip_on=True, label = r'$\gamma=4$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_five_phi, color = plt.cm.jet(0.8), linewidth=2, clip_on=True, label = r'$\gamma=5$ m$^{-2}$')
e_vs_phi_plot3.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], const_thresh_phi, color = 'k', linewidth=2, linestyle=':', clip_on=True, label = r'$\tau_c=100$ Pa')

e_vs_phi_plot3.set_xscale('log')

e_vs_phi_plot3.set_xlabel('Erosion rate [m/yr]')
e_vs_phi_plot3.set_ylabel(r'Steady-state $\phi$ [-]')

e_vs_phi_plot3.set_xlim([0.00001, 0.005])
e_vs_phi_plot3.set_ylim([0., 2])

############LOWER RIGHT SUBPLOT, MEAN Q=30 M3/S
e_vs_phi_plot4 = plt.subplot(235)

data = np.genfromtxt(lower_right_data, delimiter = ',', skip_header = 1)
bl_lower_rate = data[0:length_of_series, 9]

gamma_zero_slope = data[0:length_of_series, 15]
gamma_tenth_slope = data[length_of_series: (length_of_series * 2), 15]
gamma_twotenths_slope = data[(2 * length_of_series): (length_of_series * 3), 15]
gamma_half_slope = data[(3 * length_of_series): (length_of_series * 4), 15]
gamma_one_slope = data[(4 * length_of_series): (length_of_series * 5), 15]
gamma_two_slope = data[(5 * length_of_series): (length_of_series * 6), 15]
gamma_three_slope = data[(6 * length_of_series): (length_of_series * 7), 15]
gamma_four_slope = data[(7 * length_of_series): (length_of_series * 8), 15]
gamma_five_slope = data[(8 * length_of_series): (length_of_series * 9), 15]
const_thresh_slope = data[(9 * length_of_series):, 15]

#calculate phi values by linear regression on a moving window
gamma_zero_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_zero_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_zero_phi[i-n_points_oneway] = phi
    
gamma_tenth_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_tenth_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_tenth_phi[i-n_points_oneway] = phi
    
gamma_twotenths_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_twotenths_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_twotenths_phi[i-n_points_oneway] = phi
    
gamma_half_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_half_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_half_phi[i-n_points_oneway] = phi
    
gamma_one_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_one_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_one_phi[i-n_points_oneway] = phi
    
gamma_two_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_two_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_two_phi[i-n_points_oneway] = phi
    
gamma_three_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_three_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_three_phi[i-n_points_oneway] = phi
    
gamma_four_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway][~np.isnan(gamma_four_slope[i - n_points_oneway:i + n_points_oneway])]), np.log10(gamma_four_slope[i - n_points_oneway:i + n_points_oneway][~np.isnan(gamma_four_slope[i - n_points_oneway:i + n_points_oneway])]))[0] # your data x, y to fit
    gamma_four_phi[i-n_points_oneway] = phi
    
gamma_five_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma_five_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma_five_phi[i-n_points_oneway] = phi

const_thresh_phi = np.zeros(length_of_series - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl_lower_rate[i - n_points_oneway:i + n_points_oneway]), np.log10(const_thresh_slope[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    const_thresh_phi[i-n_points_oneway] = phi

e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_zero_phi, color = 'k', linewidth=2, clip_on=True, label = r'$\gamma=0$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_tenth_phi, color = plt.cm.jet(0.1), linewidth=2, clip_on=True, label = r'$\gamma=0.1$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_twotenths_phi, color = plt.cm.jet(0.2), linewidth=2, clip_on=True, label = r'$\gamma=0.2$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_half_phi, color = plt.cm.jet(0.3), linewidth=2, clip_on=True, label = r'$\gamma=0.5$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_one_phi, color = plt.cm.jet(0.4), linewidth=2, clip_on=True, label = r'$\gamma=1$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_two_phi, color = plt.cm.jet(0.5), linewidth=2, clip_on=True, label = r'$\gamma=2$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_three_phi, color = plt.cm.jet(0.6), linewidth=2, clip_on=True, label = r'$\gamma=3$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_four_phi, color = plt.cm.jet(0.7), linewidth=2, clip_on=True, label = r'$\gamma=4$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], gamma_five_phi, color = plt.cm.jet(0.8), linewidth=2, clip_on=True, label = r'$\gamma=5$ m$^{-2}$')
e_vs_phi_plot4.plot(bl_lower_rate[n_points_oneway:-n_points_oneway], const_thresh_phi, color = 'k', linewidth=2, linestyle=':', clip_on=True, label = r'$\tau_c=100$ Pa')

e_vs_phi_plot4.set_xscale('log')

e_vs_phi_plot4.set_xlabel('Erosion rate [m/yr]')

e_vs_phi_plot4.set_xlim([0.00001, 0.005])
e_vs_phi_plot4.set_ylim([0., 2])

handles, labels = e_vs_phi_plot4.get_legend_handles_labels()
e_vs_phi_plot4.legend(handles, labels, loc='center left', scatterpoints = 1, fontsize = 14, bbox_to_anchor=(1.05, 1))
############FINAL FIGURE POLISHING AND EXPORT
#text labeling panels
e_vs_phi.text(0.08, 0.89, 'A: $\overline{Q} = 10$ m$^3$/s, $c = 0.5$')# \n Low discharge variability')
e_vs_phi.text(0.391, 0.86, 'B: $\overline{Q} = 15$ m$^3$/s, $c = 0.5$\n Same as Fig. 5c')
e_vs_phi.text(0.08, 0.485, 'C: $\overline{Q} = 20$ m$^3$/s, $c = 0.5$')
e_vs_phi.text(0.391, 0.485, 'D: $\overline{Q} = 30$ m$^3$/s, $c = 0.5$')# \n High discharge variability')

#turn off ticks on x-axis for upper plots
e_vs_phi_plot1.axes.xaxis.set_ticklabels([])
e_vs_phi_plot2.axes.xaxis.set_ticklabels([])

#move x tick labels down
e_vs_phi_plot3.tick_params(direction='out', pad=8)
e_vs_phi_plot4.tick_params(direction='out', pad=8)

#turn off ticks on y-axis for plots 2 and 4 (right side)
e_vs_phi_plot2.axes.yaxis.set_ticklabels([])
e_vs_phi_plot4.axes.yaxis.set_ticklabels([])

#annotate top left panel with arrow showing transition zone
e_vs_phi_plot1.annotate(' ', xy=(0.00095, 1.07), xytext=(0.0006, 0.7),
            arrowprops=dict(facecolor='black', shrink=0.05),
            )

plt.tight_layout(pad=1.5, h_pad=0, w_pad=0)
e_vs_phi.savefig('shobe_etal_fig6.eps', dpi=1000, bbox_inches='tight')