# -*- coding: utf-8 -*-
"""
Created on Fri Mar 24 13:04:33 2017

@author: Charlie Shobe, University of Colorado

This script creates Figure 7 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 7 compares, in erosion rate-slope space, several different model
realizations: A no-threshold model, a constant-threshold model, three 
different block models, and the variable-threshold models calibrated to fit
those three block models. The plot shows model results from the BRaKE 
(Blocky River and Knickpoint Evolution) model.

INPUTS
------
A single .csv file contain erosion rate and slope data for each model run.
"""
from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt

#set plot font size parameter
matplotlib.rcParams.update({'font.size': 20})

#import and parse data
data = np.genfromtxt('shobe_etal_fig7_data.csv', delimiter = ',', skip_header = 1)
bl_lower_rate = data[:, 0]
base_case_slope = data[:, 1]
constant_threshold_slope = data[:, 2]
block_model_slope = data[:, 3]
taucrit_fit = data[:, 4]
block_gamma2 = data[:, 5]
tc_gamma2 = data[:, 6]
block_gammapoint5 = data[:, 7]
tc_gammapoint5 = data[:, 8]

#instantiate figure
e_vs_s = plt.figure(figsize=(9.44, 5.9))

#plot
e_vs_s_plot_2 = plt.subplot()

e_vs_s_plot_2.plot(bl_lower_rate, constant_threshold_slope, c = 'k', linewidth = 3, linestyle = '--', label = r'No blocks, constant $\tau_c=100$ Pa')
e_vs_s_plot_2.plot(bl_lower_rate, block_model_slope, c = plt.cm.jet(0.8), alpha = 0.5, linewidth = 3,  label = r'Blocks, $\gamma=5$ m$^{-2}$')
e_vs_s_plot_2.plot(bl_lower_rate, taucrit_fit, c = plt.cm.jet(0.8), linewidth = 3, linestyle = ':', label = r'No blocks, $\tau_c^{\mathrm{eff}}=300000E+40$ Pa')
e_vs_s_plot_2.plot(bl_lower_rate, block_gamma2, color = plt.cm.jet(0.5), alpha = 0.5, linewidth = 3, label = r'Blocks, $\gamma=2$ m$^{-2}$')
e_vs_s_plot_2.plot(bl_lower_rate, tc_gamma2, color = plt.cm.jet(0.5), linewidth=3, linestyle=':', label = r'No blocks, $\tau_c^{\mathrm{eff}}=120000E+30$ Pa')
e_vs_s_plot_2.plot(bl_lower_rate, block_gammapoint5, color = plt.cm.jet(0.3), alpha = 0.5, linewidth=3, label = r'Blocks, $\gamma=0.5$ m$^{-2}$')
e_vs_s_plot_2.plot(bl_lower_rate, tc_gammapoint5, color = plt.cm.jet(0.3), linewidth = 3, linestyle = ':', label = r'No blocks, $\tau_c^{\mathrm{eff}}=70000E+5$ Pa')
e_vs_s_plot_2.plot(bl_lower_rate, base_case_slope, c = 'k', linewidth = 3, label = r'No blocks, constant $\tau_c=0$ Pa')

e_vs_s_plot_2.set_xscale('log')
e_vs_s_plot_2.set_yscale('log')
plt.text(.11e-4, 1.3e-4, r'$y=1437.2x^{1.3648}$, $R^2=0.99$')

e_vs_s_plot_2.set_xlabel('Erosion rate [m/yr]')
e_vs_s_plot_2.set_ylabel('Steady-state mean slope [-]')

e_vs_s_plot_2.set_xlim([0.00001, .005])
e_vs_s_plot_2.set_ylim([0.0001, 2])

plt.legend(loc='lower right', scatterpoints=1, fontsize = 14)

############finally, figure adjustments and saving
plt.tight_layout(pad=1, h_pad=0, w_pad=0)

#vertical line at E=0.001 m/yr
e_vs_s_plot_2.axvline(x=0.001, c = 'darkgrey', linestyle='--', linewidth=2, zorder=0)

#export as .tif because transparency doesn't render in .eps
e_vs_s.savefig('shobe_etal_fig7.tif', dpi=300)