# -*- coding: utf-8 -*-
"""
Jan 18 2016

@author: Charlie Shobe, University of Colorado

This script creates Figure 8 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy and Matplotlib.

Figure 8 compares time series of channel reach profile evolution between four 
cases: low/high erosion rate in two models: the block model and the
variable-threshold model parameterization.

INPUTS
------
Four .csv files, each of which is a time series of channel elevation 
through time during a 400 ky model run. Each csv loads as a mxn matrix
where m is the number of rows (one row for each time at which elevation was
recorded) and n is the number of columns (one for each channel node).
"""
from __future__ import division
import numpy as np
import matplotlib.pyplot as plt
import matplotlib

#set matplotlib plotting parameter
matplotlib.rcParams.update({'font.size': 24})

#user parameters for shifting and normalizing longitudinal profiles
#used to keep normalized elevations between 0 and 1.
low_shift = -4 #m
low_total_bl_drop = 7 #m 
high_shift = 400
high_total_bl_drop = 500 #m

#import data
blocky_elevs_lowE = np.genfromtxt('shobe_etal_fig8_data_block_lowE.csv', 
                                  delimiter = ',', skip_header = 0)
taucrit_elevs_lowE = np.genfromtxt('shobe_etal_fig8_data_threshold_lowE.csv', 
                                   delimiter = ',', skip_header = 0)
blocky_elevs_highE = np.genfromtxt('shobe_etal_fig8_data_block_highE.csv', 
                                   delimiter = ',', skip_header = 0)
taucrit_elevs_highE = np.genfromtxt('shobe_etal_fig8_data_threshold_highE.csv', 
                                    delimiter = ',', skip_header = 0)

#shift data to keep elevations positive
blocky_elevs_lowE += low_shift
taucrit_elevs_lowE += low_shift
blocky_elevs_highE += high_shift
taucrit_elevs_highE += high_shift

#set upu x-domain
x_dist = np.arange(0,100,1) * 10

###parse data and normalize by total baselevel lowering
# block model, low erosion rate
blocky_elevs_lowE_0ky = blocky_elevs_lowE[0, :] / low_total_bl_drop
blocky_elevs_lowE_50ky = blocky_elevs_lowE[50, :] / low_total_bl_drop
blocky_elevs_lowE_100ky = blocky_elevs_lowE[100, :] / low_total_bl_drop
blocky_elevs_lowE_150ky = blocky_elevs_lowE[150, :] / low_total_bl_drop
blocky_elevs_lowE_200ky = blocky_elevs_lowE[200, :] / low_total_bl_drop
blocky_elevs_lowE_225ky = blocky_elevs_lowE[225, :] / low_total_bl_drop
blocky_elevs_lowE_250ky = blocky_elevs_lowE[250, :] / low_total_bl_drop
blocky_elevs_lowE_275ky = blocky_elevs_lowE[275, :] / low_total_bl_drop
blocky_elevs_lowE_300ky = blocky_elevs_lowE[300, :] / low_total_bl_drop
blocky_elevs_lowE_325ky = blocky_elevs_lowE[325, :] / low_total_bl_drop
blocky_elevs_lowE_350ky = blocky_elevs_lowE[350, :] / low_total_bl_drop
blocky_elevs_lowE_375ky = blocky_elevs_lowE[375, :] / low_total_bl_drop
blocky_elevs_lowE_400ky = blocky_elevs_lowE[400, :] / low_total_bl_drop

# variable-threshold model, low erosion rate
taucrit_elevs_lowE_0ky = taucrit_elevs_lowE[0, :] / low_total_bl_drop
taucrit_elevs_lowE_50ky = taucrit_elevs_lowE[50, :] / low_total_bl_drop
taucrit_elevs_lowE_100ky = taucrit_elevs_lowE[100, :] / low_total_bl_drop
taucrit_elevs_lowE_150ky = taucrit_elevs_lowE[150, :] / low_total_bl_drop
taucrit_elevs_lowE_200ky = taucrit_elevs_lowE[200, :] / low_total_bl_drop
taucrit_elevs_lowE_225ky = taucrit_elevs_lowE[225, :] / low_total_bl_drop
taucrit_elevs_lowE_250ky = taucrit_elevs_lowE[250, :] / low_total_bl_drop
taucrit_elevs_lowE_275ky = taucrit_elevs_lowE[275, :] / low_total_bl_drop
taucrit_elevs_lowE_300ky = taucrit_elevs_lowE[300, :] / low_total_bl_drop
taucrit_elevs_lowE_325ky = taucrit_elevs_lowE[325, :] / low_total_bl_drop
taucrit_elevs_lowE_350ky = taucrit_elevs_lowE[350, :] / low_total_bl_drop
taucrit_elevs_lowE_375ky = taucrit_elevs_lowE[375, :] / low_total_bl_drop
taucrit_elevs_lowE_400ky = taucrit_elevs_lowE[400, :] / low_total_bl_drop

# block model, high erosion rate
blocky_elevs_highE_0ky = blocky_elevs_highE[0, :] / high_total_bl_drop
blocky_elevs_highE_50ky = blocky_elevs_highE[50, :] / high_total_bl_drop
blocky_elevs_highE_100ky = blocky_elevs_highE[100, :] / high_total_bl_drop
blocky_elevs_highE_150ky = blocky_elevs_highE[150, :] / high_total_bl_drop
blocky_elevs_highE_200ky = blocky_elevs_highE[200, :] / high_total_bl_drop
blocky_elevs_highE_225ky = blocky_elevs_highE[225, :] / high_total_bl_drop
blocky_elevs_highE_250ky = blocky_elevs_highE[250, :] / high_total_bl_drop
blocky_elevs_highE_275ky = blocky_elevs_highE[275, :] / high_total_bl_drop
blocky_elevs_highE_300ky = blocky_elevs_highE[300, :] / high_total_bl_drop
blocky_elevs_highE_325ky = blocky_elevs_highE[325, :] / high_total_bl_drop
blocky_elevs_highE_350ky = blocky_elevs_highE[350, :] / high_total_bl_drop
blocky_elevs_highE_375ky = blocky_elevs_highE[375, :] / high_total_bl_drop
blocky_elevs_highE_400ky = blocky_elevs_highE[400, :] / high_total_bl_drop

# variable-threshold model, high erosion rate
taucrit_elevs_highE_0ky = taucrit_elevs_highE[0, :] / high_total_bl_drop
taucrit_elevs_highE_50ky = taucrit_elevs_highE[50, :] / high_total_bl_drop
taucrit_elevs_highE_100ky = taucrit_elevs_highE[100, :] / high_total_bl_drop
taucrit_elevs_highE_150ky = taucrit_elevs_highE[150, :] / high_total_bl_drop
taucrit_elevs_highE_200ky = taucrit_elevs_highE[200, :] / high_total_bl_drop
taucrit_elevs_highE_225ky = taucrit_elevs_highE[225, :] / high_total_bl_drop
taucrit_elevs_highE_250ky = taucrit_elevs_highE[250, :] / high_total_bl_drop
taucrit_elevs_highE_275ky = taucrit_elevs_highE[275, :] / high_total_bl_drop
taucrit_elevs_highE_300ky = taucrit_elevs_highE[300, :] / high_total_bl_drop
taucrit_elevs_highE_325ky = taucrit_elevs_highE[325, :] / high_total_bl_drop
taucrit_elevs_highE_350ky = taucrit_elevs_highE[350, :] / high_total_bl_drop
taucrit_elevs_highE_375ky = taucrit_elevs_highE[375, :] / high_total_bl_drop
taucrit_elevs_highE_400ky = taucrit_elevs_highE[400, :] / high_total_bl_drop

##############plot pnormalized longitudinal profiles
#normalize x-distance
norm_x_dist = x_dist / max(x_dist)
  
#instantiate figure
norm_profiles = plt.figure(figsize = (12,8))
norm_prof0 = plt.subplot(221) #blocky, low E
norm_prof1 = plt.subplot(223) #threshold, low E
norm_prof2 = plt.subplot(222) #blocky, high E
norm_prof3 = plt.subplot(224) #threshold, high E

# block model, low erosion rate
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_0ky, linestyle='-', color=plt.cm.YlGnBu(.25), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_50ky, linestyle='-', color=plt.cm.YlGnBu(.3), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_100ky, linestyle='-', color=plt.cm.YlGnBu(.4), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_150ky, linestyle='-', color=plt.cm.YlGnBu(.5), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_200ky, linestyle='-', color=plt.cm.YlGnBu(.6), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_250ky, linestyle='-', color=plt.cm.YlGnBu(.7), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_300ky, linestyle='-', color=plt.cm.YlGnBu(.8), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_350ky, linestyle='-', color=plt.cm.YlGnBu(.9), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof0.plot(norm_x_dist, blocky_elevs_lowE_400ky, linestyle='-', color=plt.cm.YlGnBu(1.0), linewidth=2, zorder = 1, label='200 ky SU')

# variable-threshold model, low erosion rate
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_0ky, linestyle='-', color=plt.cm.YlGnBu(.25), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_50ky, linestyle='-', color=plt.cm.YlGnBu(.3), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_100ky, linestyle='-', color=plt.cm.YlGnBu(.4), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_150ky, linestyle='-', color=plt.cm.YlGnBu(.5), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_200ky, linestyle='-', color=plt.cm.YlGnBu(.6), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_250ky, linestyle='-', color=plt.cm.YlGnBu(.7), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_300ky, linestyle='-', color=plt.cm.YlGnBu(.8), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_350ky, linestyle='-', color=plt.cm.YlGnBu(.9), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof1.plot(norm_x_dist, taucrit_elevs_lowE_400ky, linestyle='-', color=plt.cm.YlGnBu(1.0), linewidth=2, zorder = 1, label='200 ky SU')

# block model, high erosion rate
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_0ky, linestyle='-', color=plt.cm.YlGnBu(.25), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_50ky, linestyle='-', color=plt.cm.YlGnBu(.3), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_100ky, linestyle='-', color=plt.cm.YlGnBu(.4), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_150ky, linestyle='-', color=plt.cm.YlGnBu(.5), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_200ky, linestyle='-', color=plt.cm.YlGnBu(.6), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_250ky, linestyle='-', color=plt.cm.YlGnBu(.7), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_300ky, linestyle='-', color=plt.cm.YlGnBu(.8), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_350ky, linestyle='-', color=plt.cm.YlGnBu(.9), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof2.plot(norm_x_dist, blocky_elevs_highE_400ky, linestyle='-', color=plt.cm.YlGnBu(1.0), linewidth=2, zorder = 1, label='200 ky SU')

# variable-threshold model, high erosion rate
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_0ky, linestyle='-', color=plt.cm.YlGnBu(.25), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_50ky, linestyle='-', color=plt.cm.YlGnBu(.3), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_100ky, linestyle='-', color=plt.cm.YlGnBu(.4), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_150ky, linestyle='-', color=plt.cm.YlGnBu(.5), linewidth=2, zorder = 1, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_200ky, linestyle='-', color=plt.cm.YlGnBu(.6), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_250ky, linestyle='-', color=plt.cm.YlGnBu(.7), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_300ky, linestyle='-', color=plt.cm.YlGnBu(.8), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_350ky, linestyle='-', color=plt.cm.YlGnBu(.9), linewidth=2, zorder = 2, label='200 ky SU')
norm_prof3.plot(norm_x_dist, taucrit_elevs_highE_400ky, linestyle='-', color=plt.cm.YlGnBu(1.0), linewidth=2, zorder = 1, label='200 ky SU')

###############polish and save plot
#axis labels
norm_prof1.set_xlabel('x / L')
norm_prof3.set_xlabel('x / L')

#axis limits
norm_prof0.set_ylim([0, 1])
norm_prof0.set_xlim([0, 1])
norm_prof1.set_ylim([0, 1])
norm_prof1.set_xlim([0, 1])
norm_prof2.set_ylim([0, 1])
norm_prof2.set_xlim([0, 1])
norm_prof3.set_ylim([0, 1])
norm_prof3.set_xlim([0, 1])

#tick locations
norm_prof0.tick_params(axis='x', which='major', pad=15)
norm_prof1.tick_params(axis='x',pad=10)
norm_prof3.tick_params(axis='x',pad=10)

#plot titles
norm_prof0.set_title(r'$E=10^{-5}$ m/yr', y=1.02)
norm_prof2.set_title(r'$E=10^{-3}$ m/yr', y=1.02)

#spacing and tick labels
norm_profiles.subplots_adjust(hspace=.5)
norm_prof0.axes.xaxis.set_ticklabels([])
norm_prof2.axes.xaxis.set_ticklabels([])
norm_prof2.axes.yaxis.set_ticklabels([])
norm_prof3.axes.yaxis.set_ticklabels([])

#y-axis label
norm_profiles.text(0.01, 0.53, 'Elevation / total baselevel lowering', va='center', rotation='vertical')
plt.tight_layout(pad = 1.6, h_pad = 0, w_pad=0.3)

#text labels for which plot is which
norm_profiles.text(0.09, 0.57, 'Block model', va='center')
norm_profiles.text(0.09, 0.2, 'Threshold model', va='center')
norm_profiles.text(0.54, 0.57, 'Block model', va='center')
norm_profiles.text(0.54, 0.2, 'Threshold model', va='center')

#save plot
norm_profiles.savefig('shobe_etal_fig8.eps', dpi=1000)