# -*- coding: utf-8 -*-
"""
Created on Tue Apr 11 10:03:40 2017

@author: Charlie Shobe, University of Colorado

This script creates Figure 9 of Shobe et al (2018, JGR-ES).
It is written in Python 2.7, and uses Numpy, SciPy, and Matplotlib.

Figure 9 plots erosion rate vs. topographic exponent phi for four 
variable-threshold model parameterizations. Phi is calculated by fitting 
a line segment to a moving window of points.

INPUTS
------
One .csv file containing the output (mean slope) from a set of model runs.

"""
from __future__ import division
import matplotlib
matplotlib.use('MacOSX')
from matplotlib import rc
rc('text', usetex=True)
import numpy as np
import matplotlib.pyplot as plt
matplotlib.rcParams.update({'font.size': 20})

#define function for line segment fitting
from scipy.optimize import curve_fit
def f(x, A, B): 
    return A * x + B

#define size of moving window
n_points_oneway = 5

#define length of data series
length_of_series = 75 #number of entries for a given gamma

####import data
data = np.genfromtxt('shobe_etal_fig9_data.csv', delimiter = ',', skip_header = 1)

####separate data into colums for plotting
bl = data[:, 0]
const_thresh = data[:, 2]
gamma0_cpoint5 = data[:, 1]
gammapoint5_cpoint5 = data[:, 8]
gamma2_cpoint5 = data[:, 6]
gamma5_cpoint5 = data[:, 4]
    
#calculate phi values by linear regression on a moving window
const_thresh_phi = np.zeros(len(bl) - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl[i - n_points_oneway:i + n_points_oneway]), np.log10(const_thresh[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    const_thresh_phi[i-n_points_oneway] = phi

gamma0_cpoint5_phi = np.zeros(len(bl) - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma0_cpoint5[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma0_cpoint5_phi[i-n_points_oneway] = phi
    
gammapoint5_cpoint5_phi = np.zeros(len(bl) - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl[i - n_points_oneway:i + n_points_oneway]), np.log10(gammapoint5_cpoint5[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gammapoint5_cpoint5_phi[i-n_points_oneway] = phi
    
gamma2_cpoint5_phi = np.zeros(len(bl) - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma2_cpoint5[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma2_cpoint5_phi[i-n_points_oneway] = phi
    
gamma5_cpoint5_phi = np.zeros(len(bl) - 2 * n_points_oneway)
for i in range(n_points_oneway, length_of_series - n_points_oneway):
    phi,B = curve_fit(f, np.log10(bl[i - n_points_oneway:i + n_points_oneway]), np.log10(gamma5_cpoint5[i - n_points_oneway:i + n_points_oneway]))[0] # your data x, y to fit
    gamma5_cpoint5_phi[i-n_points_oneway] = phi

#instantiate the figure
e_vs_phi = plt.figure(figsize=(8,5))

#instantiate the subplots
cpoint5_plot = plt.subplot()

cpoint5_plot.plot(bl[n_points_oneway:-n_points_oneway], gamma0_cpoint5_phi, color = 'k', linewidth = 3, linestyle='-', label=r'$\tau_c = 0$ Pa')
cpoint5_plot.plot(bl[n_points_oneway:-n_points_oneway], gammapoint5_cpoint5_phi, color = plt.cm.jet(0.3), linewidth = 3, linestyle='-', label=r'$\tau_c^{\mathrm{eff}}$ fit to $\gamma=0.5$ m$^{-2}$')
cpoint5_plot.plot(bl[n_points_oneway:-n_points_oneway], gamma2_cpoint5_phi, color = plt.cm.jet(0.5), linewidth = 3, linestyle='-', label=r'$\tau_c^{\mathrm{eff}}$ fit to $\gamma=2$ m$^{-2}$')
cpoint5_plot.plot(bl[n_points_oneway:-n_points_oneway], gamma5_cpoint5_phi, color = plt.cm.jet(0.8), linewidth = 3, linestyle='-', label=r'$\tau_c^{\mathrm{eff}}$ fit to $\gamma=5$ m$^{-2}$')
cpoint5_plot.plot(bl[n_points_oneway:-n_points_oneway], const_thresh_phi,color = 'k', linewidth = 3, linestyle='--', label=r'$\tau_c = 100$ Pa')

############polish and save figure
#axis scale
cpoint5_plot.set_xscale('log')

#annotations
cpoint5_plot.axvline(x=0.001, c = 'darkgrey', linestyle='--', linewidth=2, zorder=0)
e_vs_phi.text(0.115, 0.94, r'$\overline{Q} = 15$ m$^3$/s$, c = 0.5$')

#legend
handles, labels = cpoint5_plot.get_legend_handles_labels()
cpoint5_plot.legend(loc='lower right', scatterpoints = 1, fontsize = 14, labelspacing=0)#, bbox_to_anchor=(1.05, 0))

#axis limits
cpoint5_plot.set_xlim(0.00001, 0.005)
cpoint5_plot.set_ylim(0.48, 1.5)

#axis labels
cpoint5_plot.set_xlabel('Erosion rate [m/yr]')
cpoint5_plot.set_ylabel(r'Steady-state $\phi$ [-]')

plt.tight_layout(pad=0, h_pad=1, w_pad=0)

#export as .eps
e_vs_phi.savefig('shobe_etal_fig9.eps', dpi=1000, bbox_inches='tight')